nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Syscon

Struct Syscon 

pub struct Syscon { /* private fields */ }
SYSCON

Implementations

Source

impl Syscon

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn memoryremap(self) -> Reg<Memoryremap, RW>

Memory Remap control register

pub const fn ahbmatprio(self) -> Reg<Ahbmatprio, RW>

AHB Matrix priority control register Priority values are 3 = highest, 0 = lowest

pub const fn cpu0stckcal(self) -> Reg<Cpu0stckcal, RW>

System tick calibration for secure part of CPU0

pub const fn cpu0nstckcal(self) -> Reg<Cpu0nstckcal, RW>

System tick calibration for non-secure part of CPU0

pub const fn cpu1stckcal(self) -> Reg<Cpu1stckcal, RW>

System tick calibration for CPU1

pub const fn nmisrc(self) -> Reg<Nmisrc, RW>

NMI Source Select

pub const fn presetctrl0(self) -> Reg<Presetctrl0, RW>

Peripheral reset control 0

pub const fn presetctrl1(self) -> Reg<Presetctrl1, RW>

Peripheral reset control 1

pub const fn presetctrl2(self) -> Reg<Presetctrl2, RW>

Peripheral reset control 2

pub const fn presetctrlset(self, n: usize) -> Reg<Presetctrlset, RW>

Peripheral reset control set register

pub const fn presetctrlclr(self, n: usize) -> Reg<Presetctrlclr, RW>

Peripheral reset control clear register

pub const fn swr_reset(self) -> Reg<SwrReset, W>

generate a software_reset

pub const fn ahbclkctrl0(self) -> Reg<Ahbclkctrl0, RW>

AHB Clock control 0

pub const fn ahbclkctrl1(self) -> Reg<Ahbclkctrl1, RW>

AHB Clock control 1

pub const fn ahbclkctrl2(self) -> Reg<Ahbclkctrl2, RW>

AHB Clock control 2

pub const fn ahbclkctrlset(self, n: usize) -> Reg<Ahbclkctrlset, RW>

Peripheral reset control register

pub const fn ahbclkctrlclr(self, n: usize) -> Reg<Ahbclkctrlclr, RW>

Peripheral reset control register

pub const fn systickclksel0(self) -> Reg<Systickclksel0, RW>

System Tick Timer for CPU0 source select

pub const fn systickclkselx0(self) -> Reg<Systickclkselx0, RW>

Peripheral reset control register

pub const fn systickclksel1(self) -> Reg<Systickclksel1, RW>

System Tick Timer for CPU1 source select

pub const fn systickclkselx1(self) -> Reg<Systickclkselx1, RW>

Peripheral reset control register

pub const fn traceclksel(self) -> Reg<Traceclksel, RW>

Trace clock source select

pub const fn ctimerclksel0(self) -> Reg<Ctimerclksel0, RW>

CTimer 0 clock source select

pub const fn ctimerclkselx0(self) -> Reg<Ctimerclkselx0, RW>

Peripheral reset control register

pub const fn ctimerclksel1(self) -> Reg<Ctimerclksel1, RW>

CTimer 1 clock source select

pub const fn ctimerclkselx1(self) -> Reg<Ctimerclkselx1, RW>

Peripheral reset control register

pub const fn ctimerclksel2(self) -> Reg<Ctimerclksel2, RW>

CTimer 2 clock source select

pub const fn ctimerclkselx2(self) -> Reg<Ctimerclkselx2, RW>

Peripheral reset control register

pub const fn ctimerclksel3(self) -> Reg<Ctimerclksel3, RW>

CTimer 3 clock source select

pub const fn ctimerclkselx3(self) -> Reg<Ctimerclkselx3, RW>

Peripheral reset control register

pub const fn ctimerclksel4(self) -> Reg<Ctimerclksel4, RW>

CTimer 4 clock source select

pub const fn ctimerclkselx4(self) -> Reg<Ctimerclkselx4, RW>

Peripheral reset control register

pub const fn mainclksela(self) -> Reg<Mainclksela, RW>

Main clock A source select

pub const fn mainclkselb(self) -> Reg<Mainclkselb, RW>

Main clock source select

pub const fn clkoutsel(self) -> Reg<Clkoutsel, RW>

CLKOUT clock source select

pub const fn pll0clksel(self) -> Reg<Pll0clksel, RW>

PLL0 clock source select

pub const fn pll1clksel(self) -> Reg<Pll1clksel, RW>

PLL1 clock source select

pub const fn adcclksel(self) -> Reg<Adcclksel, RW>

ADC clock source select

pub const fn usb0clksel(self) -> Reg<Usb0clksel, RW>

FS USB clock source select

pub const fn fcckkselx(self, n: usize) -> Reg<Fcclkselx, RW>

Peripheral reset control register

pub const fn fcclksel(self, n: usize) -> Reg<Fcclksel, RW>

Flexcomm Interface 0 clock source select for Fractional Rate Divider

pub const fn hslspiclksel(self) -> Reg<Hslspiclksel, RW>

HS LSPI clock source select

pub const fn mclkclksel(self) -> Reg<Mclkclksel, RW>

MCLK clock source select

pub const fn sctclksel(self) -> Reg<Sctclksel, RW>

SCTimer/PWM clock source select

pub const fn sdioclksel(self) -> Reg<Sdioclksel, RW>

SDIO clock source select

pub const fn systickclkdiv0(self) -> Reg<Systickclkdiv0, RW>

System Tick Timer divider for CPU0

pub const fn systickclkdiv1(self) -> Reg<Systickclkdiv1, RW>

System Tick Timer divider for CPU1

pub const fn traceclkdiv(self) -> Reg<Traceclkdiv, RW>

TRACE clock divider

pub const fn flexfrgctrl(self, n: usize) -> Reg<Flexfrgctrl, RW>

Fractional rate divider for flexcomm 0

pub const fn flexfrgxctrl(self, n: usize) -> Reg<Flexfrgxctrl, RW>

Peripheral reset control register

pub const fn ahbclkdiv(self) -> Reg<Ahbclkdiv, RW>

System clock divider

pub const fn clkoutdiv(self) -> Reg<Clkoutdiv, RW>

CLKOUT clock divider

pub const fn frohfdiv(self) -> Reg<Frohfdiv, RW>

FRO_HF (96MHz) clock divider

pub const fn wdtclkdiv(self) -> Reg<Wdtclkdiv, RW>

WDT clock divider

pub const fn adcclkdiv(self) -> Reg<Adcclkdiv, RW>

ADC clock divider

pub const fn usb0clkdiv(self) -> Reg<Usb0clkdiv, RW>

USB0 Clock divider

pub const fn mclkdiv(self) -> Reg<Mclkdiv, RW>

I2S MCLK clock divider

pub const fn sctclkdiv(self) -> Reg<Sctclkdiv, RW>

SCT/PWM clock divider

pub const fn sdioclkdiv(self) -> Reg<Sdioclkdiv, RW>

SDIO clock divider

pub const fn pll0clkdiv(self) -> Reg<Pll0clkdiv, RW>

PLL0 clock divider

pub const fn clockgenupdatelockout(self) -> Reg<Clockgenupdatelockout, RW>

Control clock configuration registers access (like xxxDIV, xxxSEL)

pub const fn fmccr(self) -> Reg<Fmccr, RW>

FMC configuration register

pub const fn usb0needclkctrl(self) -> Reg<Usb0needclkctrl, RW>

USB0 need clock control

pub const fn usb0needclkstat(self) -> Reg<Usb0needclkstat, RW>

USB0 need clock status

pub const fn fmcflush(self) -> Reg<Fmcflush, W>

FMCflush control

pub const fn mclkio(self) -> Reg<Mclkio, RW>

MCLK control

pub const fn usb1needclkctrl(self) -> Reg<Usb1needclkctrl, RW>

USB1 need clock control

pub const fn usb1needclkstat(self) -> Reg<Usb1needclkstat, RW>

USB1 need clock status

pub const fn sdioclkctrl(self) -> Reg<Sdioclkctrl, RW>

SDIO CCLKIN phase and delay control

pub const fn pll1ctrl(self) -> Reg<Pll1ctrl, RW>

PLL1 550m control

pub const fn pll1stat(self) -> Reg<Pll1stat, RW>

PLL1 550m status

pub const fn pll1ndec(self) -> Reg<Pll1ndec, RW>

PLL1 550m N divider

pub const fn pll1mdec(self) -> Reg<Pll1mdec, RW>

PLL1 550m M divider

pub const fn pll1pdec(self) -> Reg<Pll1pdec, RW>

PLL1 550m P divider

pub const fn pll0ctrl(self) -> Reg<Pll0ctrl, RW>

PLL0 550m control

pub const fn pll0stat(self) -> Reg<Pll0stat, RW>

PLL0 550m status

pub const fn pll0ndec(self) -> Reg<Pll0ndec, RW>

PLL0 550m N divider

pub const fn pll0pdec(self) -> Reg<Pll0pdec, RW>

PLL0 550m P divider

pub const fn pll0sscg0(self) -> Reg<Pll0sscg0, RW>

PLL0 Spread Spectrum Wrapper control register 0

pub const fn pll0sscg1(self) -> Reg<Pll0sscg1, RW>

PLL0 Spread Spectrum Wrapper control register 1

pub const fn funcretentionctrl(self) -> Reg<Funcretentionctrl, RW>

Functional retention control register

pub const fn cpuctrl(self) -> Reg<Cpuctrl, RW>

CPU Control for multiple processors

pub const fn cpboot(self) -> Reg<Cpboot, RW>

Coprocessor Boot Address

pub const fn cpstat(self) -> Reg<Cpstat, RW>

CPU Status

pub const fn clock_ctrl(self) -> Reg<ClockCtrl, RW>

Various system clock controls : Flash clock (48 MHz) control, clocks to Frequency Measures

pub const fn comp_int_ctrl(self) -> Reg<CompIntCtrl, RW>

Comparator Interrupt control

pub const fn comp_int_status(self) -> Reg<CompIntStatus, RW>

Comparator Interrupt status

pub const fn autoclkgateoverride(self) -> Reg<Autoclkgateoverride, RW>

Control automatic clock gating

pub const fn gpiopsync(self) -> Reg<Gpiopsync, RW>

Enable bypass of the first stage of synchonization inside GPIO_INT module

pub const fn debug_lock_en(self) -> Reg<DebugLockEn, RW>

Control write access to security registers.

pub const fn debug_features(self) -> Reg<DebugFeatures, RW>

Cortex M33 (CPU0) and micro Cortex M33 (CPU1) debug features control.

pub const fn debug_features_dp(self) -> Reg<DebugFeaturesDp, RW>

Cortex M33 (CPU0) and micro Cortex M33 (CPU1) debug features control DUPLICATE register.

pub const fn key_block(self) -> Reg<KeyBlock, W>

block quiddikey/PUF all index.

pub const fn debug_auth_beacon(self) -> Reg<DebugAuthBeacon, RW>

Debug authentication BEACON register

pub const fn cpucfg(self) -> Reg<Cpucfg, RW>

CPUs configuration register

pub const fn device_id0(self) -> Reg<DeviceId0, R>

Device ID

pub const fn dieid(self) -> Reg<Dieid, R>

Chip revision ID and Number